==> onos-yang-runtime-2.2.0-sources.jar: org/onosproject/yang/gen/v1/ietfl3vpnsvc/rev20160730/ietfl3vpnsvc/accessvpnpolicy/vpnattachment/attachmentflavor/DefaultVpnId.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.ietfl3vpnsvc.rev20160730.ietfl3vpnsvc.accessvpnpolicy.vpnattachment.attachmentflavor;

import java.util.BitSet;
import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.gen.v1.ietfl3vpnsvc.rev20160730.ietfl3vpnsvc.SiteRole;
import org.onosproject.yang.gen.v1.ietfl3vpnsvc.rev20160730.ietfl3vpnsvc.accessvpnpolicy.vpnattachment.AttachmentFlavor;
import org.onosproject.yang.model.InnerModelObject;

/**
 * Represents the implementation of vpnId.
 *
 * <p>
 * valueLeafFlags identify the leafs whose value are explicitly set
 * Applicable in protocol edit and query operation.
 * </p>
 */
public class DefaultVpnId extends InnerModelObject implements VpnId {
    protected Object vpnId;
    protected Class<? extends SiteRole> siteRole;
    protected BitSet valueLeafFlags = new BitSet();

    @Override
    public Object vpnId() {
        return vpnId;
    }

    @Override
    public Class<? extends SiteRole> siteRole() {
        return siteRole;
    }

    @Override
    public BitSet valueLeafFlags() {
        return valueLeafFlags;
    }

    @Override
    public void vpnId(Object vpnId) {
        valueLeafFlags.set(LeafIdentifier.VPNID.getLeafIndex());
        this.vpnId = vpnId;
    }

    @Override
    public void siteRole(Class<? extends SiteRole> siteRole) {
        valueLeafFlags.set(LeafIdentifier.SITEROLE.getLeafIndex());
        this.siteRole = siteRole;
    }

    @Override
    public int hashCode() {
        return Objects.hash(vpnId, siteRole, valueLeafFlags);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof DefaultVpnId) {
            DefaultVpnId other = (DefaultVpnId) obj;
            return
                Objects.equals(vpnId, other.vpnId) &&
                Objects.equals(siteRole, other.siteRole) &&
                Objects.equals(valueLeafFlags, other.valueLeafFlags);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("vpnId=" + vpnId)
            .add("siteRole=" + siteRole)
            .add("valueLeafFlags=" + valueLeafFlags)
            .toString();
    }


    /**
     * Creates an instance of defaultVpnId.
     */
    public DefaultVpnId() {
    }


    @Override
    public boolean isLeafValueSet(LeafIdentifier leaf) {
        return valueLeafFlags.get(leaf.getLeafIndex());
    }

}

==> onos-yang-runtime-2.3.1-sources.jar: org/onosproject/yang/gen/v1/ietfl3vpnsvc/rev20160730/ietfl3vpnsvc/accessvpnpolicy/vpnattachment/attachmentflavor/DefaultVpnId.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.ietfl3vpnsvc.rev20160730.ietfl3vpnsvc.accessvpnpolicy.vpnattachment.attachmentflavor;

import java.util.BitSet;
import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.gen.v1.ietfl3vpnsvc.rev20160730.ietfl3vpnsvc.SiteRole;
import org.onosproject.yang.gen.v1.ietfl3vpnsvc.rev20160730.ietfl3vpnsvc.accessvpnpolicy.vpnattachment.AttachmentFlavor;
import org.onosproject.yang.model.InnerModelObject;

/**
 * Represents the implementation of vpnId.
 *
 * <p>
 * valueLeafFlags identify the leafs whose value are explicitly set
 * Applicable in protocol edit and query operation.
 * </p>
 */
public class DefaultVpnId extends InnerModelObject implements VpnId {
    protected Object vpnId;
    protected Class<? extends SiteRole> siteRole;
    protected BitSet valueLeafFlags = new BitSet();

    @Override
    public Object vpnId() {
        return vpnId;
    }

    @Override
    public Class<? extends SiteRole> siteRole() {
        return siteRole;
    }

    @Override
    public BitSet valueLeafFlags() {
        return valueLeafFlags;
    }

    @Override
    public void vpnId(Object vpnId) {
        valueLeafFlags.set(LeafIdentifier.VPNID.getLeafIndex());
        this.vpnId = vpnId;
    }

    @Override
    public void siteRole(Class<? extends SiteRole> siteRole) {
        valueLeafFlags.set(LeafIdentifier.SITEROLE.getLeafIndex());
        this.siteRole = siteRole;
    }

    @Override
    public int hashCode() {
        return Objects.hash(vpnId, siteRole, valueLeafFlags);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof DefaultVpnId) {
            DefaultVpnId other = (DefaultVpnId) obj;
            return
                Objects.deepEquals(vpnId, other.vpnId) &&
                Objects.deepEquals(siteRole, other.siteRole) &&
                Objects.deepEquals(valueLeafFlags, other.valueLeafFlags);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("vpnId=" + vpnId)
            .add("siteRole=" + siteRole)
            .add("valueLeafFlags=" + valueLeafFlags)
            .toString();
    }


    /**
     * Creates an instance of defaultVpnId.
     */
    public DefaultVpnId() {
    }


    @Override
    public boolean isLeafValueSet(LeafIdentifier leaf) {
        return valueLeafFlags.get(leaf.getLeafIndex());
    }

}
